@@ -157,6 +157,13 @@ class Line(ChartPart):
                 series_obj["dataGroupId"] = series_obj["name"]
 
         spec["legend.data"] = list(data.columns)
+        if "areaStyle" in spec["series"][0]:
+            xAxis["boundaryGap"] = False
+
+        spec["tooltip"] = {
+            "trigger": "axis",
+            "axisPointer": {"type": "cross", "label": {"backgroundColor": "#6a7985"}},
+        }
 
         return spec
 
@@ -181,9 +188,9 @@ class Pie(ChartPart):
 
         data = data.groupby(color)[value].mean()
 
-        spec["xAxis"] = {}
+        del spec["xAxis"]
 
-        spec["yAxis"] = {}
+        del spec["yAxis"]
 
         # TODO: 应该依据是否开启动画设置 groupId
         series_data = [
@@ -207,11 +214,12 @@ class Pie(ChartPart):
                 isinstance(series_obj["universalTransition"], bool)
                 and series_obj["universalTransition"]
             ):
-                
 
                 series_obj["universalTransition"] = {
                     "enabled": True,
-                    "seriesKey": data.index.values[0] if len(data.index.values)==1 else list(data.index.values),
+                    "seriesKey": data.index.values[0]
+                    if len(data.index.values) == 1
+                    else list(data.index.values),
                 }
             spec.add_series(series_obj)
 
